Authors
================

* Matthew Westcott matthew.westcott@torchbox.com twitter: @gasmanic
* David Cranwell david.cranwell@torchbox.com twitter: @davecranwell
* Karl Hobley karl.hobley@torchbox.com

Contributors
============

* Helen Chapman helen.chapman@torchbox.com
* Balazs Endresz balazs.endresz@torchbox.com
* Neal Todd neal.todd@torchbox.com
* Paul Hallett (twilio) hello@phalt.co
* Tom Dyson
* Serafeim Papastefanos
* Łukasz Bołdys
* peterarenot
* Levi Gross
* Delgermurun Purevkhuu
* Lewis Cowper
* Stephen Newey
* Ryan Foster
* v1kku
* Miguel Vieira
* Ben Emery
* David Smith
* Ben Margolis
* Tom Talbot
* Jeffrey Hearn
* Robert Clark
* Tim Heap
* Nathan Brizendine
* thenewguy

Translators
===========

* Basque: Unai Zalakain
* Bulgarian: Lyuboslav Petrov
* Catalan: David Llop
* Chinese: Lihan Li, tulpar008, wwj718
* French: Sylvain Fankhauser
* Galician: fooflare
* German: Karl Sander, Johannes Spielmann
* Greek: Serafeim Papastefanos
* Mongolian: Delgermurun Purevkhuu
* Polish: Łukasz Bołdys
* Portuguese: Jose Lourenco
* Portuguese Brazil: Gilson Filho
* Romanian: Dan Braghis
* Russian: ice9, HNKNTA
* Spanish: Unai Zalakain, fooflare
* Traditional Chinese (Taiwan): wdv4758h
